@@ -107,6 +107,8 @@ int main(
   int c;
   int errflg = 0;
   int any_failed = 0;
+  int purge_completed = FALSE;
+  int located = FALSE;
   char *pc;
 
   char job_id[PBS_MAXCLTJOBID]; /* from the command line */
@@ -117,7 +119,7 @@ int main(
 
   char extend[1024];
 
-#define GETOPT_ARGS "m:pW:"
+#define GETOPT_ARGS "cm:pW:"
 
   extend[0] = '\0';
 
@@ -126,6 +128,20 @@ int main(
     switch (c)
       {
 
+      case 'c':
+
+        if (extend[0] != '\0')
+          {
+          errflg++;
+
+          break;
+          }
+
+        snprintf(extend,sizeof(extend),"%s%ld",PURGECOMP,(long)(time(NULL)));
+        purge_completed = TRUE;
+
+        break;
+
       case 'm':
 
         /* add delete message */
@@ -215,13 +231,19 @@ int main(
       }
     }    /* END while (c) */
 
+  if (purge_completed)
+    {
+    strcpy(server_out,pbs_default());
+    goto cnt;
+    }
+
   if ((errflg != 0) || (optind >= argc))
     {
-    static char usage[] = "usage: qdel [{ -p | -W delay | -m message}] [<JOBID>[<JOBID>]|'all'|'ALL']...\n";
+    static char usage[] = "usage: qdel [{ -c | -p | -W delay | -m message}] [<JOBID>[<JOBID>]|'all'|'ALL']...\n";
 
     fprintf(stderr, "%s", usage);
 
-    fprintf(stderr, "       -m, -p, and -W are mutually exclusive\n");
+    fprintf(stderr, "       -c, -m, -p, and -W are mutually exclusive\n");
 
     exit(2);
     }
@@ -230,7 +252,7 @@ int main(
     {
     int connect;
     int stat = 0;
-    int located = FALSE;
+
 
     /* check to see if user specified 'all' to delete all jobs */
 
@@ -357,10 +379,10 @@ void qdel_all(
 
     /* 
      * Don't bother deleting jobs that are 'C'omplete or 'E'xiting
-     * Unless we are Purging, then try these jobs as well
+     * Unless we are Purging, then try 'C'ompleted jobs as well
      */
     
-    if ((strstr(extend,DELPURGE) != NULL) ||
+    if (((strstr(extend,DELPURGE) != NULL) && (*state != 'E')) ||
         ((*state != 'E') && (*state != 'C')))
       {
       retries = 0;
