@@ -212,8 +212,9 @@ struct grpcache
  * define the size of the array.
  */
 
-/* sync w/job_attr_def[]  (NOTE:  must maintain same ordering between enum and job_attr_def[] table in src/server/job_at) */
-/* sync w/TJobAttr[] table in src/resmom/request.c */
+/* sync w/job_attr_def[]  (NOTE:  must maintain same ordering between enum and
+   job_attr_def[] table in src/server/job_attr_def.c) */
+/* sync w/TJobAttr[] table in src/resmom/requests.c */
 
 enum job_atr
   {
@@ -277,6 +278,8 @@ enum job_atr
   JOB_ATR_start_count, /* number of times the job has been started */
   JOB_ATR_chkptdir,    /* directory where job checkpoint file is stored */
   JOB_ATR_chkptname,   /* name of checkpoint file */
+  JOB_ATR_comp_time,  /* time when job was completed */
+  JOB_ATR_reported, /* tracks whether job has been reported to scheduler */
 #include "site_job_attr_enum.h"
 
   JOB_ATR_UNKN,  /* the special "unknown" type    */
@@ -425,7 +428,7 @@ struct job
   time_t  ji_chkpttime; /* periodic checkpoint time */
   time_t  ji_chkptnext; /* next checkpoint time */
   time_t  ji_sampletim; /* last usage sample time, irix only */
-  pid_t  ji_momsubt; /* pid of mom subtask   */
+  pid_t  ji_momsubt;    /* pid of mom subtask   */
   int (*ji_mompost)();       /* ptr to post processing func  */
 
   struct batch_request *ji_preq; /* hold request until finish_exec */
@@ -788,6 +791,7 @@ task *task_find A_((
 #define JOB_EXEC_INITRMG  -6 /* job aborted on MOM init, chkpt, ok migrate */
 #define JOB_EXEC_BADRESRT -7 /* job restart failed */
 #define JOB_EXEC_CMDFAIL  -8 /* exec() of user command failed */
+#define JOB_EXEC_STDOUTFAIL -9 /* could not create/open stdout stderr files */
 
 extern void  add_dest A_((job *));
 extern void  depend_clrrdy A_((job *));
