@@ -172,6 +172,8 @@
 #define ATTR_start_count "start_count"
 #define ATTR_chkptdir    "checkpoint_dir"    /* user specified directory for checkpoint files */
 #define ATTR_chkptname   "checkpoint_name"   /* user specified name of checkpoint file */
+#define ATTR_comp_time   "comp_time"
+#define ATTR_reported    "reported"
 
 /* additional queue attributes names */
 
@@ -218,7 +220,7 @@
 /* NOTE: steps for adding new attribute described in ??? */
 /*  - create #define ATTR_* in include/pbs_ifl.h
     - insert SRV_ATR_* in include/server.h
-    - add SRV_ATR_* in include/qmgr_svr_public.h
+    - add ATTR_* in include/qmgr_svr_public.h
     - insert structure in server/svr_attr_def.c
         NOTE:  structure must be in same relative position as SRV_ATR_*
     - insert usage code in proper location
@@ -263,9 +265,14 @@
 #define ATTR_servername  "server_name"
 #define ATTR_logfilemaxsize "log_file_max_size"
 #define ATTR_logfilerolldepth "log_file_roll_depth"
+#define ATTR_logkeepdays "log_keep_days"
 #define ATTR_nextjobnum  "next_job_number"
 #define ATTR_extraresc   "extra_resc"
 #define ATTR_schedversion "sched_version"
+#define ATTR_acctkeepdays "accounting_keep_days"
+#define ATTR_lockfile "lock_file"
+#define ATTR_credentiallifetime "credential_lifetime"
+#define ATTR_jobmustreport "job_must_report"
 
 /* additional node "attributes" names */
 
@@ -290,6 +297,7 @@
 
 #define DELDELAY  "deldelay=" /* see qdel.c */
 #define DELPURGE  "delpurge="   /* see qdel.c */
+#define PURGECOMP  "purgecomplete="   /* see req_delete.c */
 #define EXECQUEONLY  "exec_queue_only"   /* see req_stat.c */
 #define RERUNFORCE "force"
 
@@ -346,6 +354,12 @@
 #define SIG_RESUME "resume"
 #define SIG_SUSPEND "suspend"
 
+
+/* WARNING: be careful changing these PBS_MAX* values.  They can result in a
+   change in the structure of the .JB file, and binary incompatibilities between
+   versions of TORQUE.  Do not change in a -fixes branch */
+
+
 #define PBS_MAXHOSTNAME  64 /* max host name length */
 #ifndef MAXPATHLEN
 #define MAXPATHLEN  1024 /* max path name length */
@@ -356,7 +370,7 @@
 #define MAX_NOTE  256 /* max node note length */
 #define MAX_NOTE_STR  "256" /* max node note length as a string literal (this MUST match MAX_NOTE) */
 
-#define PBS_MAXUSER  16 /* max user name length */
+#define PBS_MAXUSER  32 /* max user name length */
 #define PBS_MAXGRPN  16 /* max group name length */
 #define PBS_MAXQUEUENAME 15 /* max queue name length */
 #define PBS_MAXSERVERNAME PBS_MAXHOSTNAME /* max server name length */
