@@ -144,15 +144,20 @@ enum srv_atr
   SRV_ATR_SubmitHosts,
   SRV_ATR_AllowNodeSubmit,
   SRV_ATR_AllowProxyUser,
-  SRV_ATR_AutoNodeNP,
+  SRV_ATR_AutoNodeNP,            /* 50 */
   SRV_ATR_LogFileMaxSize,
   SRV_ATR_LogFileRollDepth,
+  SRV_ATR_LogKeepDays,
   SRV_ATR_NextJobNumber,
   SRV_ATR_tokens,
   SRV_ATR_NetCounter,
   SRV_ATR_ExtraResc,
   SRV_ATR_ServerName,
   SRV_ATR_SchedVersion,
+  SRV_ATR_AcctKeepDays,          /* 60 */
+  SRV_ATR_lockfile,
+  SRV_ATR_CredentialLifetime,
+  SRV_ATR_JobMustReport,
 #include "site_svr_attr_enum.h"
   /* This must be last */
   SRV_ATR_LAST
@@ -216,7 +221,7 @@ extern struct server server;
 
 /* function prototypes */
 
-extern int svr_recov A_((char *));
+extern int svr_recov A_((char *, int));
 extern int svr_save A_((struct server *, int));
 
 
