@@ -292,7 +292,7 @@ char *msg_jobnorerun  = "job is not rerunnable";
 char *msg_routebad = "Job rejected by all possible destinations";
 char *msg_momreject = "Execution server rejected request";
 char *msg_nosyncmstr = "No master found for sync job set";
-char *msg_sched_called  = "Scheduler sent command %s";
+char *msg_sched_called 	= "Scheduler was sent the command %s";
 char *msg_sched_nocall  = "Could not contact Scheduler";
 char *msg_listnr_called = "Listener %d sent command %s";
 char *msg_listnr_nocall  = "Could not contact Listener";
