@@ -450,8 +450,11 @@ scan_for_terminated(void)
 
       while (ptask != NULL)
         {
-        if (ptask->ti_qs.ti_sid == pid)
+        if ((ptask->ti_qs.ti_sid == pid) &&
+            (ptask->ti_qs.ti_status != TI_STATE_EXITED))
+          {
           break;
+          }
 
         ptask = (task *)GET_NEXT(ptask->ti_jobtask);
         }  /* END while (ptask) */
@@ -462,13 +465,21 @@ scan_for_terminated(void)
       pjob = (job *)GET_PRIOR(pjob->ji_alljobs);
       }  /* END while (pjob != NULL) */
 
+    if (WIFEXITED(statloc))
+      exiteval = WEXITSTATUS(statloc);
+    else if (WIFSIGNALED(statloc))
+      exiteval = WTERMSIG(statloc) + 0x100;
+    else
+      exiteval = 1;
+
     if (pjob == NULL)
       {
       if (LOGLEVEL >= 1)
         {
-        sprintf(log_buffer, "pid %d not tracked, exitcode=%d",
+        sprintf(log_buffer, "pid %d not tracked, statloc=%d, exitval=%d",
                 pid,
-                statloc);
+                statloc,
+                exiteval);
 
         log_record(
           PBSEVENT_JOB,
@@ -480,13 +491,6 @@ scan_for_terminated(void)
       continue;
       }  /* END if (pjob == NULL) */
 
-    if (WIFEXITED(statloc))
-      exiteval = WEXITSTATUS(statloc);
-    else if (WIFSIGNALED(statloc))
-      exiteval = WTERMSIG(statloc) + 0x100;
-    else
-      exiteval = 1;
-
     if (pid == pjob->ji_momsubt)
       {
       /* PID matches job mom subtask */
@@ -578,9 +582,7 @@ scan_for_terminated(void)
     kill_task(ptask, SIGKILL, 0);
 
     ptask->ti_qs.ti_exitstat = exiteval;
-
     ptask->ti_qs.ti_status   = TI_STATE_EXITED;
-
     task_save(ptask);
 
     sprintf(log_buffer, "%s: job %s task %d terminated, sid=%d",
