@@ -447,6 +447,10 @@ mom_server *mom_server_find_by_ip(
     if (pms->SStream != -1)
       {
       addr = rpp_getaddr(pms->SStream);
+      if(addr == NULL)
+        {
+        return(NULL);
+        }
       ipaddr = ntohl(addr->sin_addr.s_addr);
 
       if (ipaddr == search_ipaddr)
@@ -1496,7 +1500,6 @@ int mom_server_check_connection(
         {
         return(0);
         }
-
       }
     }    /* END if (pms->SStream == -1) */
 
@@ -2052,7 +2055,7 @@ mom_server *mom_server_valid_message_source(
           netaddr(addr),
           "(server not authorized)");
 
-  log_err(-1, id, log_buffer);
+  log_ext(-1,id,log_buffer,LOG_ALERT);
 
   rpp_close(stream);
 
@@ -2112,7 +2115,7 @@ void is_request(
     sprintf(log_buffer, "protocol version %d unknown",
             version);
 
-    log_err(-1, id, log_buffer);
+    log_ext(-1,id,log_buffer,LOG_ALERT);
 
     rpp_close(stream);
 
@@ -2232,7 +2235,7 @@ void is_request(
       sprintf(log_buffer, "unknown command %d sent",
               command);
 
-      log_err(-1, id, log_buffer);
+      log_ext(-1,id,log_buffer,LOG_ALERT);
 
       goto err;
     }  /* END switch(command) */
@@ -2250,7 +2253,7 @@ err:
           dis_emsg[ret],
           (addr != NULL) ? netaddr(addr) : "???");
 
-  log_err(-1, id, log_buffer);
+  log_ext(-1,id,log_buffer,LOG_ALERT);
 
   rpp_close(stream);
 
