@@ -109,6 +109,7 @@
 #include "server.h"
 #include "queue.h"
 #include "job.h"
+#include "resource.h"
 #include "work_task.h"
 #include "tracking.h"
 #include "svrfunc.h"
@@ -174,6 +175,7 @@ extern char *path_queues;
 extern char *path_spool;
 extern char *path_svrdb;
 extern char *path_svrdb_new;
+extern char *path_svrlog;
 extern char *path_track;
 extern char *path_nodes;
 extern char *path_nodes_new;
@@ -195,6 +197,8 @@ extern tlist_head task_list_timed;
 extern tlist_head task_list_event;
 extern time_t  time_now;
 
+extern int a_opt_init;
+
 extern int LOGLEVEL;
 extern char *plogenv;
 
@@ -284,7 +288,6 @@ int pbsd_init(
   int type)  /* type of initialization   */
 
   {
-  int a_opt = -1;
   int baselen;
   char basen[MAXPATHLEN+1];
 
@@ -492,7 +495,10 @@ int pbsd_init(
 
   /* 2. set up the various paths and other global variables we need */
 
-  path_priv      = build_path(path_home, PBS_SVR_PRIVATE, suffix_slash);
+  if(path_priv == NULL)
+    {
+    path_priv      = build_path(path_home, PBS_SVR_PRIVATE, suffix_slash);
+    }
 
   path_arrays  = build_path(path_priv, PBS_ARRAYDIR, suffix_slash);
 
@@ -504,10 +510,15 @@ int pbsd_init(
 
   path_acct  = build_path(path_priv, PBS_ACCT,     suffix_slash);
 
-  path_svrdb     = build_path(path_priv, PBS_SERVERDB, NULL);
+  if(path_svrdb == NULL)
+    {
+    path_svrdb     = build_path(path_priv, PBS_SERVERDB, NULL);
+    }
 
   path_svrdb_new = build_path(path_priv, PBS_SERVERDB, new_tag);
 
+  path_svrlog = build_path(path_home, PBS_LOGFILES, suffix_slash);
+
   path_track  = build_path(path_priv, PBS_TRACKING, NULL);
 
   path_nodes  = build_path(path_priv, NODE_DESCRIP, NULL);
@@ -520,7 +531,10 @@ int pbsd_init(
 
   path_nodenote_new = build_path(path_priv, NODE_NOTE, new_tag);
 
-  init_resc_defs();
+  if (svr_resc_def == NULL)
+    {
+    init_resc_defs();
+    }
 
 #if !defined(DEBUG) && !defined(NO_SECURITY_CHECK)
 
@@ -563,11 +577,6 @@ int pbsd_init(
 
   /* 3. Set default server attibutes values */
 
-  if (server.sv_attr[(int)SRV_ATR_scheduling].at_flags & ATR_VFLAG_SET)
-    {
-    a_opt = server.sv_attr[(int)SRV_ATR_scheduling].at_val.at_long;
-    }
-
   for (i = 0;i < SRV_ATR_LAST;i++)
     clear_attr(&server.sv_attr[i], &svr_attr_def[i]);
 
@@ -624,7 +633,7 @@ int pbsd_init(
     {
     /* Open the server database (save file) and read it in */
 
-    if ((rc != 0) || ((rc = svr_recov(path_svrdb)) == -1))
+    if ((rc != 0) || ((rc = svr_recov(path_svrdb, FALSE)) == -1)) 
       {
       log_err(rc, "pbsd_init", msg_init_baddb);
 
@@ -674,11 +683,11 @@ int pbsd_init(
 
   /* 7. Set up other server and global variables */
 
-  if (a_opt != -1)
+  if (a_opt_init != -1)
     {
     /* a_option was set, overrides saved value of scheduling attr */
 
-    server.sv_attr[(int)SRV_ATR_scheduling].at_val.at_long = a_opt;
+    server.sv_attr[(int)SRV_ATR_scheduling].at_val.at_long = a_opt_init;
     server.sv_attr[(int)SRV_ATR_scheduling].at_flags |=
       ATR_VFLAG_SET;
     }
@@ -893,7 +902,7 @@ int pbsd_init(
             }
           else
             {
-            /* FIXME: what shoudl we do here?  we won't beable to finish 
+            /* FIXME: what should we do here?  we won't be able to finish 
                cloning this array because the initial job file is missing */
             }
 
@@ -906,19 +915,6 @@ int pbsd_init(
 
         if ((pjob = job_recov(pdirent->d_name)) != NULL)
           {
-          if (pjob->ji_qs.ji_substate == JOB_SUBSTATE_COMPLETE)
-            {
-            /* ignore/remove completed job */
-
-            /* for some reason, if a completed job is recovered, and it is
-             * forcibly purged with 'qdel -p', it will get deleted a 
-             * second time resulting in a segfault */
-
-            job_purge(pjob);
-
-            continue;
-            }
-
           if (pbsd_init_job(pjob, type) == FAILURE)
             {
             log_event(
@@ -1399,8 +1395,7 @@ static int pbsd_init_job(
 
     case JOB_SUBSTATE_COMPLETE:
 
-      /* NOOP - completed jobs are already purged above */
-      /* for some reason, this doesn't actually work */
+      /* Completed jobs are no longer purged on startup */
 
       pwt = set_task(WORK_Immed, 0, on_job_exit, (void *)pjob);
 
@@ -2059,3 +2054,50 @@ static void init_abt_job(
 
   return;
   }
+
+
+
+
+/*
+ * This just reads in the server attributes from the server db.
+ */
+
+int get_svr_attr(
+
+  int type)		/* type of initialization   */
+
+  {
+  static char id[] = "get_svr_attr";
+  int	 rc;
+  char	*suffix_slash = "/";
+  
+  if (type != RECOV_CREATE) 
+    {
+    /* Open the server database (save file) and read it in */
+
+    if(path_priv == NULL)
+      {
+      path_priv = build_path(path_home, PBS_SVR_PRIVATE, suffix_slash);
+      }
+    if(path_svrdb == NULL)
+      {
+      path_svrdb     = build_path(path_priv, PBS_SERVERDB, NULL);
+      }
+
+    if (svr_resc_def == NULL)
+      {
+      init_resc_defs();
+      }
+
+    if (((rc = chk_save_file(path_svrdb))!= 0) || ((rc = svr_recov(path_svrdb, TRUE)) == -1)) 
+      {
+      log_err(rc, id ,msg_init_baddb);
+
+      return(-1);
+      }
+
+    } 
+
+  return(0);
+  }  /* END get_svr_attr() */
+
